@@ -470,6 +470,10 @@ class AuthService:
         check()
         return make_call(auth_pb2_grpc.AuthServiceStub(channel).ForgotPassword, request)
 
+    def GeneratePromoCode(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).GeneratePromoCode, request)
+
     def GoogleSignin(self, request):
         check()
         return make_call(auth_pb2_grpc.AuthServiceStub(channel).GoogleSignin, request)
@@ -516,6 +520,12 @@ class AuthService:
     def ForgotPasswordResponse(self, **kwargs):
         return auth_pb2.ForgotPasswordResponse(**kwargs)
 
+    def GeneratePromoCodeRequest(self, **kwargs):
+        return auth_pb2.GeneratePromoCodeRequest(**kwargs)
+
+    def GeneratePromoCodeResponse(self, **kwargs):
+        return auth_pb2.GeneratePromoCodeResponse(**kwargs)
+
     def GoogleSigninRequest(self, **kwargs):
         return auth_pb2.GoogleSigninRequest(**kwargs)
 
